@@ -3,7 +3,7 @@ import re
 
 from collections import namedtuple
 from math import ceil
-from flask import request, json, make_response
+from flask import request, make_response
 
 from . import ctx
 
@@ -150,6 +150,8 @@ def json_body_required(func):
 
 
 def json_response(data, code=200):
+    from flask import json
+
     json_kwargs = {}
     if ctx.cfg.get("debug"):
         json_kwargs["indent"] = 4
